
=============================
 Transifex Command-Line Tool
=============================

The Transifex Command-line Client is a command line tool that enables you to easily manage your translations within a project without the need of an elaborate UI system.

You can use the command line client to easily create new resources, map locale files to translations and synchronize your Transifex project with your local repository and vice verca. Translators and localization managers can also use it to handle large volumes of translation files easily and without much hassle.

Check the full documentation at http://help.transifex.net/user-guide/client/


Installing
==========

You can install the latest version of transifex-client running 
``pip install transifex-client`` or ``easy_install transifex-client``
You can also install the `in-development version`_ of transifex-client with
``pip install transifex-client==dev`` or ``easy_install transifex-client==dev``.

.. _in-development version: http://code.indifex.com/transifex-client/get/tip.gz#egg=transifex-client-dev

